/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.javancss;

import ch.hortis.sonar.model.Metric;
import org.sonar.commons.measures.Measure;
import org.sonar.plugins.api.Language;
import org.sonar.plugins.api.Languages;
import org.sonar.plugins.api.jobs.AbstractJob;
import org.sonar.plugins.api.jobs.Entity;
import org.sonar.plugins.api.metrics.CoreMetrics;

import java.util.Arrays;
import java.util.List;

public class CommentRatioJob extends AbstractJob {
  public boolean shouldExecuteOnEntity(Entity node) {
    return node.isProject() || node.isPackage();
  }

  @Override
  public List<Metric> dependsOnMetrics() {
    return Arrays.asList(CoreMetrics.NLOC, CoreMetrics.COMMENT_LINES);
  }

  @Override
  public List<Metric> generatesMetrics() {
    return Arrays.asList(CoreMetrics.COMMENT_RATIO);
  }

  public void execute(Entity resource) {
    Measure ncss = resource.getMeasure(CoreMetrics.NLOC);
    Measure comments = resource.getMeasure(CoreMetrics.COMMENT_LINES);
    if (ncss != null && comments !=null) {
      resource.addMeasure(CoreMetrics.COMMENT_RATIO, 100.0 * (comments.getValue() / (comments.getValue() + ncss.getValue())));
    }
  }

  protected Language shouldExecuteOnLanguage() {
    return Languages.JAVA;
  }
}
